#!/usr/bin/env perl
use Dancer;
use example_FakeCGI;
dance;
